Package {tesselle}


Title: Easily Install and Load 'tesselle' Packages
Version: 1.7.0
Maintainer: Nicolas Frerebeau <nicolas.frerebeau@u-bordeaux-montaigne.fr>
Description: Easy install and load key packages from the 'tesselle' suite in a single step. The 'tesselle' suite is a collection of packages for research and teaching in archaeology. These packages focus on quantitative analysis methods developed for archaeology. The 'tesselle' packages are designed to work seamlessly together and to complement general-purpose and other specialized statistical packages. These packages can be used to explore and analyze common data types in archaeology: count data, compositional data and chronological data. Learn more about 'tesselle' at https://www.tesselle.org.
License: GPL (≥ 3)
URL: https://codeberg.org/tesselle/tesselle, https://packages.tesselle.org/tesselle/, https://tesselle.r-universe.dev/tesselle
BugReports: https://codeberg.org/tesselle/tesselle/issues
Imports: ananke (≥ 0.3.0), dimensio (≥ 0.14.1), folio (≥ 1.5.1), isopleuros (≥ 1.4.0), kairos (≥ 2.3.0), khroma (≥ 1.17.0), nexus (≥ 0.6.0), tabula (≥ 3.3.2)
Encoding: UTF-8
X-schema.org-applicationCategory: Archaeological Science
X-schema.org-isPartOf: https://www.tesselle.org
X-schema.org-keywords: archaeological-science, archaeology, statistics, r-package
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-06-16 12:45:11 UTC; nfrerebeau
Author: Nicolas Frerebeau ORCID iD [aut, cre], Brice Lebrun ORCID iD [art] (Logo designer), Université Bordeaux Montaigne ROR ID [fnd], CNRS ROR ID [fnd]
Repository: CRAN
Date/Publication: 2026-06-16 14:50:02 UTC

tesselle: Easily Install and Load 'tesselle' Packages

Description

logo

Easy install and load key packages from the 'tesselle' suite in a single step. The 'tesselle' suite is a collection of packages for research and teaching in archaeology. These packages focus on quantitative analysis methods developed for archaeology. The 'tesselle' packages are designed to work seamlessly together and to complement general-purpose and other specialized statistical packages. These packages can be used to explore and analyze common data types in archaeology: count data, compositional data and chronological data. Learn more about 'tesselle' at https://www.tesselle.org.

Details

Version 1.7.0
License GPL-3
CRAN DOI doi:10.32614/CRAN.package.tesselle
Zenodo DOI doi:10.5281/zenodo.6500491

Archéosciences Bordeaux (UMR 6034)
Maison de l'Archéologie
Université Bordeaux Montaigne
33607 Pessac cedex
France

Author(s)

Maintainer: Nicolas Frerebeau nicolas.frerebeau@u-bordeaux-montaigne.fr (ORCID)

Authors:

Other contributors:

See Also

Useful links: